@@ -15,15 +15,21 @@ class JauthAdminBase(admin.ModelAdmin):
 
 
 class AccountKitAdmin(JauthAdminBase):
-    exclude = ()
+    raw_id_fields = [
+        "user",
+    ]
 
 
 class FacebookAdmin(JauthAdminBase):
-    exclude = ()
+    raw_id_fields = [
+        "user",
+    ]
 
 
 class GoogleAdmin(JauthAdminBase):
-    exclude = ()
+    raw_id_fields = [
+        "user",
+    ]
 
 
 if hasattr(settings, "ACCOUNT_KIT_APP_ID") and settings.ACCOUNT_KIT_APP_ID:
